@@ -1,8 +1,7 @@
 package Geo::Coordinates::Converter::Datum::Wgs72;
-
 use strict;
 use warnings;
-use base qw( Geo::Coordinates::Converter::Datum );
+use parent 'Geo::Coordinates::Converter::Datum';
 
 sub name { 'wgs72' }
 sub radius { 6378135 }
